@@ -2,12 +2,12 @@
 """
 Package init file
 """
-import graph
 import bpmn_diagram_exception
 import bpmn_diagram_export
 import bpmn_diagram_import
 import bpmn_diagram_layouter
 import bpmn_diagram_metrics
+import bpmn_diagram_rep
 import bpmn_diagram_visualizer
 import bpmn_import_utils
 import bpmn_process_csv_export
@@ -16,4 +16,4 @@ import grid_cell_class
 
 __all__ = ["bpmn_diagram_exception", "bpmn_diagram_export", "bpmn_diagram_import", "bpmn_diagram_layouter",
            "bpmn_diagram_exception", "bpmn_diagram_metrics", "bpmn_diagram_visualizer", "bpmn_import_utils",
-           "bpmn_process_csv_export", "diagram_layout_metrics", "grid_cell_class", "graph"]
+           "bpmn_process_csv_export", "diagram_layout_metrics", "grid_cell_class", "bpmn_diagram_rep"]
