@@ -2,6 +2,5 @@
 """
 Package init file
 """
-import bpmn_diagram_rep
 from classes import *
-__all__ = ["bpmn_diagram_rep", "classes"]
+__all__ = ["classes"]
